@@ -323,6 +323,7 @@ for kind in [
     KubeResourceKind(api_version="batch/v1", name="Job", parse_kind_state=KubeResourceKind.parse_state_job),
     KubeResourceKind(api_version="apps/v1", name="Deployment"),
     KubeResourceKind(api_version="v1", name="ConfigMap"),
+    KubeResourceKind(api_version="v1", name="Secret"),
 ]:
     KubeResourceKind.register_global_kind(kind)
 
@@ -392,7 +393,7 @@ class KubeResourceDescriptor:
 
     @property
     def spec(self) -> dict:
-        return self.body.get("spec")
+        return self.body.get("spec", {})
 
     @property
     def status(self) -> dict:
@@ -422,10 +423,6 @@ class KubeResourceDescriptor:
     def metadata(self) -> dict:
         return self.body.get("metadata", {})
 
-    @property
-    def spec(self) -> dict:
-        return self.body.get("spec", {})
-
     @property
     def api_version(self) -> str:
         return self.kind.api_version
